summaryrefslogtreecommitdiffstats
path: root/ppapi/cpp/instance.h
diff options
context:
space:
mode:
authornfullagar@google.com <nfullagar@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2011-09-06 23:11:53 +0000
committernfullagar@google.com <nfullagar@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2011-09-06 23:11:53 +0000
commitd3a250fc8802f10bc22d9f04475867821fa45f57 (patch)
tree6bcdec51bd5fd7949882aa2f03da94f7a7def95a /ppapi/cpp/instance.h
parent5031ca3bb62745e1da95bffbf401db75df03115f (diff)
downloadchromium_src-d3a250fc8802f10bc22d9f04475867821fa45f57.zip
chromium_src-d3a250fc8802f10bc22d9f04475867821fa45f57.tar.gz
chromium_src-d3a250fc8802f10bc22d9f04475867821fa45f57.tar.bz2
Move PPAPI graphics3d and opengles interfaces out of Dev.
BUG= http://code.google.com/p/chromium/issues/detail?id=94320 TEST= various nacl exmaples, try bots Review URL: http://codereview.chromium.org/7737013 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@99855 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ppapi/cpp/instance.h')
-rw-r--r--ppapi/cpp/instance.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ppapi/cpp/instance.h b/ppapi/cpp/instance.h
index ea145f9..528c08a 100644
--- a/ppapi/cpp/instance.h
+++ b/ppapi/cpp/instance.h
@@ -21,7 +21,7 @@ struct PP_InputEvent;
namespace pp {
class Graphics2D;
-class Graphics3D_Dev;
+class Graphics3D;
class InputEvent;
class ImageData;
class Point;
@@ -275,12 +275,12 @@ class Instance {
/// Refer to <code>BindGraphics(const Graphics2D& graphics)</code> for
/// further information.
///
/// @param[in] graphics A <code>Graphics3D_Dev</code> to bind.
///
/// @return true if bind was successful or false if the device was not the
/// correct type. On success, a reference to the device will be held by the
/// instance, so the caller can release its reference if it chooses.
- bool BindGraphics(const Graphics3D_Dev& graphics);
+ bool BindGraphics(const Graphics3D& graphics);
/// Binds the given Surface3D as the current display surface.
/// Refer to <code>BindGraphics(const Graphics2D& graphics)</code> for
@@ -275,12 +275,12 @@ class Instance {
/// further information.
///
- /// @param[in] graphics A <code>Graphics3D_Dev</code> to bind.
+ /// @param[in] graphics A <code>Graphics3D</code> to bind.
///
/// @return true if bind was successful or false if the device was not the